==> myfaces-tobago-5.0.0-source-release.zip: tobago-5.0.0/tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/css/CssClassUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.renderkit.css;

import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;

/**
 * Helpful for tests.
 */
class CssClassUtils {

  /**
   * Checks, if CSS class names are defined in the file.
   */
  static List<CssItem> compareCss(final String cssFileName, final CssItem[] cssItems) throws IOException {

    final List<CssItem> missing = new ArrayList<>();

    final String fileContent = new String(Files.readAllBytes(Paths.get(cssFileName)), StandardCharsets.UTF_8);

    for (final CssItem cssItem : cssItems) {
      if (!containsClassName(fileContent, cssItem.getName())) {
        missing.add(cssItem);
      }
    }

    return missing;
  }

  private static boolean containsClassName(final String content, final String className) {
    return content.contains("." + className + " ")
        || content.contains("." + className + "{")
        || content.contains("." + className + ",")
        || content.contains("." + className + ":")
        || content.contains("." + className + ".")
        || content.contains("." + className + ">");
  }
}

==> myfaces-tobago-6.9.0-source-release.zip: tobago-6.9.0/tobago-core/src/main/java/org/apache/myfaces/tobago/renderkit/css/CssClassUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.renderkit.css;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * Helpful for tests. Not for use in production.
 */
class CssClassUtils {

  /**
   * Checks, if CSS class names are defined in the file.
   */
  static List<CssItem> compareCss(final String cssFileName, final CssItem[] cssItems) throws IOException {

    final List<CssItem> missing = new ArrayList<>();
    final String fileContent = FileTestUtils.fileToString(cssFileName);

    for (final CssItem cssItem : cssItems) {
      if (!containsClassName(fileContent, cssItem.getName())) {
        missing.add(cssItem);
      }
    }

    return missing;
  }

  private static boolean containsClassName(final String content, final String className) {
    return content.contains("." + className + " ")
        || content.contains("." + className + "{")
        || content.contains("." + className + ",")
        || content.contains("." + className + ":")
        || content.contains("." + className + ".")
        || content.contains("." + className + ">");
  }
}
